# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from .classifier import Classifier
from .classifier_version import ClassifierVersion
from .classify_run import ClassifyRun
from .edit_run import EditRun
from .extract_run import ExtractRun
from .extractor import Extractor
from .extractor_version import ExtractorVersion
from .parse_run_status import ParseRunStatus
from .split_run import SplitRun
from .splitter import Splitter
from .splitter_version import SplitterVersion
from .step_run import StepRun
from .workflow import Workflow
from .workflow_run import WorkflowRun


class WebhookEvent_WorkflowRunCompleted(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["workflow_run.completed"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="workflow_run.completed")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: WorkflowRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_WorkflowRunFailed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["workflow_run.failed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="workflow_run.failed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: WorkflowRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_WorkflowRunNeedsReview(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["workflow_run.needs_review"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="workflow_run.needs_review")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: WorkflowRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_WorkflowRunRejected(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["workflow_run.rejected"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="workflow_run.rejected")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: WorkflowRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_WorkflowRunCancelled(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["workflow_run.cancelled"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="workflow_run.cancelled")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: WorkflowRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_WorkflowRunStepRunProcessed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["workflow_run.step_run.processed"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="workflow_run.step_run.processed")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: StepRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ExtractRunProcessed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["extract_run.processed"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="extract_run.processed")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: ExtractRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ExtractRunFailed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["extract_run.failed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="extract_run.failed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: ExtractRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ClassifyRunProcessed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["classify_run.processed"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="classify_run.processed")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: ClassifyRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ClassifyRunFailed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["classify_run.failed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="classify_run.failed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: ClassifyRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_SplitRunProcessed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["split_run.processed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="split_run.processed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: SplitRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_SplitRunFailed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["split_run.failed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="split_run.failed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: SplitRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ParseRunProcessed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["parse_run.processed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="parse_run.processed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: ParseRunStatus

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ParseRunFailed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["parse_run.failed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="parse_run.failed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: ParseRunStatus

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_EditRunProcessed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["edit_run.processed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="edit_run.processed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: EditRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_EditRunFailed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["edit_run.failed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="edit_run.failed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: EditRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_WorkflowCreated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["workflow.created"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="workflow.created")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Workflow

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_WorkflowDeployed(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["workflow.deployed"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="workflow.deployed")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Workflow

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_WorkflowDeleted(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["workflow.deleted"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="workflow.deleted")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Workflow

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ExtractorCreated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["extractor.created"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="extractor.created")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Extractor

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ExtractorUpdated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["extractor.updated"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="extractor.updated")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Extractor

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ExtractorDeleted(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["extractor.deleted"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="extractor.deleted")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Extractor

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ExtractorDraftUpdated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["extractor.draft.updated"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="extractor.draft.updated")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Extractor

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ExtractorVersionPublished(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["extractor.version.published"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="extractor.version.published")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: ExtractorVersion

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ClassifierCreated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["classifier.created"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="classifier.created")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Classifier

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ClassifierUpdated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["classifier.updated"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="classifier.updated")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Classifier

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ClassifierDeleted(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["classifier.deleted"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="classifier.deleted")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Classifier

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ClassifierDraftUpdated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["classifier.draft.updated"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="classifier.draft.updated")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Classifier

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_ClassifierVersionPublished(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["classifier.version.published"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="classifier.version.published")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: ClassifierVersion

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_SplitterCreated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["splitter.created"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="splitter.created")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Splitter

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_SplitterUpdated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["splitter.updated"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="splitter.updated")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Splitter

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_SplitterDeleted(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[typing.Literal["splitter.deleted"], FieldMetadata(alias="eventType")] = (
        pydantic.Field(alias="eventType", default="splitter.deleted")
    )
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Splitter

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_SplitterDraftUpdated(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["splitter.draft.updated"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="splitter.draft.updated")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: Splitter

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class WebhookEvent_SplitterVersionPublished(UncheckedBaseModel):
    """
    Union of all webhook event types. Use `eventType` as the discriminator
    to determine the specific event type and narrow the `payload` type.

    Example usage in TypeScript:
    ```typescript
    function handleWebhook(event: Extend.WebhookEvent) {
      switch (event.eventType) {
        case "workflow_run.completed":
          // event.payload is typed as WorkflowRun
          console.log(event.payload.status);
          break;
        case "extract_run.processed":
          // event.payload is typed as ExtractRun
          console.log(event.payload.output);
          break;
      }
    }
    ```
    """

    event_type: typing_extensions.Annotated[
        typing.Literal["splitter.version.published"], FieldMetadata(alias="eventType")
    ] = pydantic.Field(alias="eventType", default="splitter.version.published")
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    payload: SplitterVersion

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


WebhookEvent = typing_extensions.Annotated[
    typing.Union[
        WebhookEvent_WorkflowRunCompleted,
        WebhookEvent_WorkflowRunFailed,
        WebhookEvent_WorkflowRunNeedsReview,
        WebhookEvent_WorkflowRunRejected,
        WebhookEvent_WorkflowRunCancelled,
        WebhookEvent_WorkflowRunStepRunProcessed,
        WebhookEvent_ExtractRunProcessed,
        WebhookEvent_ExtractRunFailed,
        WebhookEvent_ClassifyRunProcessed,
        WebhookEvent_ClassifyRunFailed,
        WebhookEvent_SplitRunProcessed,
        WebhookEvent_SplitRunFailed,
        WebhookEvent_ParseRunProcessed,
        WebhookEvent_ParseRunFailed,
        WebhookEvent_EditRunProcessed,
        WebhookEvent_EditRunFailed,
        WebhookEvent_WorkflowCreated,
        WebhookEvent_WorkflowDeployed,
        WebhookEvent_WorkflowDeleted,
        WebhookEvent_ExtractorCreated,
        WebhookEvent_ExtractorUpdated,
        WebhookEvent_ExtractorDeleted,
        WebhookEvent_ExtractorDraftUpdated,
        WebhookEvent_ExtractorVersionPublished,
        WebhookEvent_ClassifierCreated,
        WebhookEvent_ClassifierUpdated,
        WebhookEvent_ClassifierDeleted,
        WebhookEvent_ClassifierDraftUpdated,
        WebhookEvent_ClassifierVersionPublished,
        WebhookEvent_SplitterCreated,
        WebhookEvent_SplitterUpdated,
        WebhookEvent_SplitterDeleted,
        WebhookEvent_SplitterDraftUpdated,
        WebhookEvent_SplitterVersionPublished,
    ],
    UnionMetadata(discriminant="event_type"),
]
update_forward_refs(WebhookEvent_WorkflowRunCompleted)
update_forward_refs(WebhookEvent_WorkflowRunFailed)
update_forward_refs(WebhookEvent_WorkflowRunNeedsReview)
update_forward_refs(WebhookEvent_WorkflowRunRejected)
update_forward_refs(WebhookEvent_WorkflowRunCancelled)
update_forward_refs(WebhookEvent_WorkflowRunStepRunProcessed)
update_forward_refs(WebhookEvent_ExtractRunProcessed)
update_forward_refs(WebhookEvent_ExtractRunFailed)
update_forward_refs(WebhookEvent_EditRunProcessed)
update_forward_refs(WebhookEvent_EditRunFailed)
update_forward_refs(WebhookEvent_ExtractorCreated)
update_forward_refs(WebhookEvent_ExtractorUpdated)
update_forward_refs(WebhookEvent_ExtractorDeleted)
update_forward_refs(WebhookEvent_ExtractorDraftUpdated)
update_forward_refs(WebhookEvent_ExtractorVersionPublished)



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class EditConfigAdvancedOptionsParams(typing_extensions.TypedDict):
    """
    Advanced options for the edit operation.
    """

    table_parsing_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="tableParsingEnabled")]
    ]
    """
    Whether to parse table regions as arrays of objects. Defaults to `false`.
    """

    flatten_pdf: typing_extensions.NotRequired[typing_extensions.Annotated[bool, FieldMetadata(alias="flattenPdf")]]
    """
    Whether to flatten the PDF (form widgets will not be editable with a PDF edit). Defaults to `true`.
    """

    radio_enums_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="radioEnumsEnabled")]
    ]
    """
    Whether to model radio fields as enums. This ensures only one radio widget is filled. Defaults to false.
    """

    native_fields_only: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="nativeFieldsOnly")]
    ]
    """
    If enabled, only native AcroForm from the PDF will be imported and used in the schema (skips object detection). Defaults to false.
    """



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt


class BatchRunEntityVersion_ExtractorVersionParams(typing_extensions.TypedDict):
    object: typing.Literal["extractor_version"]
    id: str
    description: typing.Optional[str]
    version: str
    extractor_id: typing_extensions.Annotated[str, FieldMetadata(alias="extractorId")]
    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]


class BatchRunEntityVersion_ClassifierVersionParams(typing_extensions.TypedDict):
    object: typing.Literal["classifier_version"]
    id: str
    description: typing.Optional[str]
    version: str
    classifier_id: typing_extensions.Annotated[str, FieldMetadata(alias="classifierId")]
    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]


class BatchRunEntityVersion_SplitterVersionParams(typing_extensions.TypedDict):
    object: typing.Literal["splitter_version"]
    id: str
    description: typing.Optional[str]
    version: str
    splitter_id: typing_extensions.Annotated[str, FieldMetadata(alias="splitterId")]
    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]


BatchRunEntityVersionParams = typing.Union[
    BatchRunEntityVersion_ExtractorVersionParams,
    BatchRunEntityVersion_ClassifierVersionParams,
    BatchRunEntityVersion_SplitterVersionParams,
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ExtractAdvancedOptionsExcelSheetSelectionStrategy(enum.StrEnum):
    """
    Strategy for selecting sheets from Excel documents.
    """

    INTELLIGENT = "intelligent"
    ALL = "all"
    FIRST = "first"
    LAST = "last"
    _UNKNOWN = "__EXTRACTADVANCEDOPTIONSEXCELSHEETSELECTIONSTRATEGY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ExtractAdvancedOptionsExcelSheetSelectionStrategy":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        intelligent: typing.Callable[[], T_Result],
        all_: typing.Callable[[], T_Result],
        first: typing.Callable[[], T_Result],
        last: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ExtractAdvancedOptionsExcelSheetSelectionStrategy.INTELLIGENT:
            return intelligent()
        if self is ExtractAdvancedOptionsExcelSheetSelectionStrategy.ALL:
            return all_()
        if self is ExtractAdvancedOptionsExcelSheetSelectionStrategy.FIRST:
            return first()
        if self is ExtractAdvancedOptionsExcelSheetSelectionStrategy.LAST:
            return last()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .legacy_extract_chunking_options_chunk_selection_strategy import LegacyExtractChunkingOptionsChunkSelectionStrategy
from .legacy_extract_chunking_options_chunking_strategy import LegacyExtractChunkingOptionsChunkingStrategy


class LegacyExtractChunkingOptions(UncheckedBaseModel):
    chunking_strategy: typing_extensions.Annotated[
        typing.Optional[LegacyExtractChunkingOptionsChunkingStrategy], FieldMetadata(alias="chunkingStrategy")
    ] = pydantic.Field(alias="chunkingStrategy", default=None)
    """
    The strategy to use for chunking the document.
    """

    page_chunk_size: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="pageChunkSize")] = (
        pydantic.Field(alias="pageChunkSize", default=None)
    )
    """
    The size of page chunks.
    """

    chunk_selection_strategy: typing_extensions.Annotated[
        typing.Optional[LegacyExtractChunkingOptionsChunkSelectionStrategy],
        FieldMetadata(alias="chunkSelectionStrategy"),
    ] = pydantic.Field(alias="chunkSelectionStrategy", default=None)
    """
    The strategy to use for selecting chunks.
    """

    custom_semantic_chunking_rules: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="customSemanticChunkingRules")
    ] = pydantic.Field(alias="customSemanticChunkingRules", default=None)
    """
    Custom rules for semantic chunking.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_config_json import ExtractConfigJsonParams
from .extract_config_legacy import ExtractConfigLegacyParams

ExtractConfigParams = typing.Union[ExtractConfigJsonParams, ExtractConfigLegacyParams]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.parse_config_chunking_strategy_type import ParseConfigChunkingStrategyType
from .parse_config_chunking_strategy_options import ParseConfigChunkingStrategyOptionsParams


class ParseConfigChunkingStrategyParams(typing_extensions.TypedDict):
    """
    Strategy for dividing the document into chunks.
    """

    type: typing_extensions.NotRequired[ParseConfigChunkingStrategyType]
    """
    The type of chunking strategy. Supported values:
    
    * `page`: Chunk document by pages.
    * `document`: Entire document is a single chunk. Essentially no chunking.
    * `section`: Split by logical sections. Not supported for target=spatial.
    """

    options: typing_extensions.NotRequired[ParseConfigChunkingStrategyOptionsParams]
    """
    Additional options for the chunking strategy.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .external_data_validation_result_response import ExternalDataValidationResultResponseParams


class ExternalDataValidationResultParams(typing_extensions.TypedDict):
    """
    The result of an external data validation step.
    """

    response: ExternalDataValidationResultResponseParams
    """
    The response from the external validation endpoint.
    """



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError as core_api_error_ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.forbidden_error import ForbiddenError
from ..errors.internal_server_error import InternalServerError
from ..errors.not_found_error import NotFoundError
from ..errors.payment_required_error import PaymentRequiredError
from ..errors.too_many_requests_error import TooManyRequestsError
from ..errors.unauthorized_error import UnauthorizedError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..requests.extract_config_json import ExtractConfigJsonParams
from ..types.api_error import ApiError as types_api_error_ApiError
from ..types.extract_run import ExtractRun
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.processor_run_status import ProcessorRunStatus
from ..types.run_metadata import RunMetadata
from ..types.run_priority import RunPriority
from ..types.run_source import RunSource
from ..types.run_source_id import RunSourceId
from ..types.sort_by import SortBy
from ..types.sort_dir import SortDir
from .requests.extract_runs_create_request_extractor import ExtractRunsCreateRequestExtractorParams
from .requests.extract_runs_create_request_file import ExtractRunsCreateRequestFileParams
from .types.extract_runs_delete_response import ExtractRunsDeleteResponse
from .types.extract_runs_list_response import ExtractRunsListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawExtractRunsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        status: typing.Optional[ProcessorRunStatus] = None,
        extractor_id: typing.Optional[str] = None,
        source_id: typing.Optional[RunSourceId] = None,
        source: typing.Optional[RunSource] = None,
        file_name_contains: typing.Optional[str] = None,
        sort_by: typing.Optional[SortBy] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ExtractRunsListResponse]:
        """
        List all extract runs.

        Returns a summary of each run. Use `GET /extract_runs/{id}` to retrieve the full object including `output` and `config`.

        Parameters
        ----------
        status : typing.Optional[ProcessorRunStatus]

        extractor_id : typing.Optional[str]
            Filters extract runs by the extractor ID. If not provided, all extract runs are returned.

            Example: `"ex_BMdfq_yWM3sT-ZzvCnA3f"`

        source_id : typing.Optional[RunSourceId]
            Filters runs by the source ID.

        source : typing.Optional[RunSource]
            Filters runs by the source that created them. If not provided, runs from all sources are returned.

        file_name_contains : typing.Optional[str]
            Filters runs by the name of the file. Only returns runs where the file name contains this string.

            Example: `"invoice"`

        sort_by : typing.Optional[SortBy]

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ExtractRunsListResponse]
            You will get a list of summaries for each extract run. These are shortened versions of the full extract run object.

            To get the full object, use the [Get Extract Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/extract/get-extract-run) endpoint.
        """
        _response = self._client_wrapper.httpx_client.request(
            "extract_runs",
            method="GET",
            params={
                "status": status,
                "extractorId": extractor_id,
                "sourceId": source_id,
                "source": source,
                "fileNameContains": file_name_contains,
                "sortBy": sort_by,
                "sortDir": sort_dir,
                "nextPageToken": next_page_token,
                "maxPageSize": max_page_size,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRunsListResponse,
                    construct_type(
                        type_=ExtractRunsListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def create(
        self,
        *,
        file: ExtractRunsCreateRequestFileParams,
        extractor: typing.Optional[ExtractRunsCreateRequestExtractorParams] = OMIT,
        config: typing.Optional[ExtractConfigJsonParams] = OMIT,
        priority: typing.Optional[RunPriority] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ExtractRun]:
        """
        Extract structured data from a file using an existing extractor or an inline configuration.

        The request returns immediately with a `PROCESSING` status. Use webhooks or poll the Get Extract Run endpoint for results.

        Parameters
        ----------
        file : ExtractRunsCreateRequestFileParams
            The file to be extracted from. Files can be provided as a URL, Extend file ID, or raw text.

        extractor : typing.Optional[ExtractRunsCreateRequestExtractorParams]
            Reference to an existing extractor. One of `extractor` or `config` must be provided.

        config : typing.Optional[ExtractConfigJsonParams]
            Inline extract configuration. One of `extractor` or `config` must be provided.

        priority : typing.Optional[RunPriority]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ExtractRun]
            Extract completed successfully
        """
        _response = self._client_wrapper.httpx_client.request(
            "extract_runs",
            method="POST",
            json={
                "extractor": convert_and_respect_annotation_metadata(
                    object_=extractor, annotation=ExtractRunsCreateRequestExtractorParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ExtractConfigJsonParams, direction="write"
                ),
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=ExtractRunsCreateRequestFileParams, direction="write"
                ),
                "priority": priority,
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRun,
                    construct_type(
                        type_=ExtractRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[ExtractRun]:
        """
        Retrieve details about a specific extract run, including its status, outputs, and any edits made during review.

        A common use case for this endpoint is to poll for the status and final output of an extract run when using the [Create Extract Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/extract/create-extract-run) endpoint. For instance, if you do not want to not configure webhooks to receive the output via completion/failure events.

        Parameters
        ----------
        id : str
            The unique identifier for this extract run.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ExtractRun]
            Successfully retrieved extract run
        """
        _response = self._client_wrapper.httpx_client.request(
            f"extract_runs/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRun,
                    construct_type(
                        type_=ExtractRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ExtractRunsDeleteResponse]:
        """
        Delete an extract run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the extract run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ExtractRunsDeleteResponse]
            Extractor run deleted successfully
        """
        _response = self._client_wrapper.httpx_client.request(
            f"extract_runs/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRunsDeleteResponse,
                    construct_type(
                        type_=ExtractRunsDeleteResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def cancel(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[ExtractRun]:
        """
        Cancel an in-progress extract run.

        Note: Only extract runs with a status of `"PROCESSING"` can be cancelled. Extractor runs that have already completed, failed, or been cancelled cannot be cancelled again.

        Parameters
        ----------
        id : str
            The ID of the extract run to cancel.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ExtractRun]
            Extractor run cancelled successfully
        """
        _response = self._client_wrapper.httpx_client.request(
            f"extract_runs/{jsonable_encoder(id)}/cancel",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRun,
                    construct_type(
                        type_=ExtractRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )


class AsyncRawExtractRunsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        status: typing.Optional[ProcessorRunStatus] = None,
        extractor_id: typing.Optional[str] = None,
        source_id: typing.Optional[RunSourceId] = None,
        source: typing.Optional[RunSource] = None,
        file_name_contains: typing.Optional[str] = None,
        sort_by: typing.Optional[SortBy] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ExtractRunsListResponse]:
        """
        List all extract runs.

        Returns a summary of each run. Use `GET /extract_runs/{id}` to retrieve the full object including `output` and `config`.

        Parameters
        ----------
        status : typing.Optional[ProcessorRunStatus]

        extractor_id : typing.Optional[str]
            Filters extract runs by the extractor ID. If not provided, all extract runs are returned.

            Example: `"ex_BMdfq_yWM3sT-ZzvCnA3f"`

        source_id : typing.Optional[RunSourceId]
            Filters runs by the source ID.

        source : typing.Optional[RunSource]
            Filters runs by the source that created them. If not provided, runs from all sources are returned.

        file_name_contains : typing.Optional[str]
            Filters runs by the name of the file. Only returns runs where the file name contains this string.

            Example: `"invoice"`

        sort_by : typing.Optional[SortBy]

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ExtractRunsListResponse]
            You will get a list of summaries for each extract run. These are shortened versions of the full extract run object.

            To get the full object, use the [Get Extract Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/extract/get-extract-run) endpoint.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "extract_runs",
            method="GET",
            params={
                "status": status,
                "extractorId": extractor_id,
                "sourceId": source_id,
                "source": source,
                "fileNameContains": file_name_contains,
                "sortBy": sort_by,
                "sortDir": sort_dir,
                "nextPageToken": next_page_token,
                "maxPageSize": max_page_size,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRunsListResponse,
                    construct_type(
                        type_=ExtractRunsListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def create(
        self,
        *,
        file: ExtractRunsCreateRequestFileParams,
        extractor: typing.Optional[ExtractRunsCreateRequestExtractorParams] = OMIT,
        config: typing.Optional[ExtractConfigJsonParams] = OMIT,
        priority: typing.Optional[RunPriority] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ExtractRun]:
        """
        Extract structured data from a file using an existing extractor or an inline configuration.

        The request returns immediately with a `PROCESSING` status. Use webhooks or poll the Get Extract Run endpoint for results.

        Parameters
        ----------
        file : ExtractRunsCreateRequestFileParams
            The file to be extracted from. Files can be provided as a URL, Extend file ID, or raw text.

        extractor : typing.Optional[ExtractRunsCreateRequestExtractorParams]
            Reference to an existing extractor. One of `extractor` or `config` must be provided.

        config : typing.Optional[ExtractConfigJsonParams]
            Inline extract configuration. One of `extractor` or `config` must be provided.

        priority : typing.Optional[RunPriority]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ExtractRun]
            Extract completed successfully
        """
        _response = await self._client_wrapper.httpx_client.request(
            "extract_runs",
            method="POST",
            json={
                "extractor": convert_and_respect_annotation_metadata(
                    object_=extractor, annotation=ExtractRunsCreateRequestExtractorParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ExtractConfigJsonParams, direction="write"
                ),
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=ExtractRunsCreateRequestFileParams, direction="write"
                ),
                "priority": priority,
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRun,
                    construct_type(
                        type_=ExtractRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def retrieve(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ExtractRun]:
        """
        Retrieve details about a specific extract run, including its status, outputs, and any edits made during review.

        A common use case for this endpoint is to poll for the status and final output of an extract run when using the [Create Extract Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/extract/create-extract-run) endpoint. For instance, if you do not want to not configure webhooks to receive the output via completion/failure events.

        Parameters
        ----------
        id : str
            The unique identifier for this extract run.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ExtractRun]
            Successfully retrieved extract run
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"extract_runs/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRun,
                    construct_type(
                        type_=ExtractRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ExtractRunsDeleteResponse]:
        """
        Delete an extract run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the extract run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ExtractRunsDeleteResponse]
            Extractor run deleted successfully
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"extract_runs/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRunsDeleteResponse,
                    construct_type(
                        type_=ExtractRunsDeleteResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def cancel(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ExtractRun]:
        """
        Cancel an in-progress extract run.

        Note: Only extract runs with a status of `"PROCESSING"` can be cancelled. Extractor runs that have already completed, failed, or been cancelled cannot be cancelled again.

        Parameters
        ----------
        id : str
            The ID of the extract run to cancel.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ExtractRun]
            Extractor run cancelled successfully
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"extract_runs/{jsonable_encoder(id)}/cancel",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRun,
                    construct_type(
                        type_=ExtractRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.parse_config_block_options_tables_target_format import ParseConfigBlockOptionsTablesTargetFormat
from .parse_config_block_options_tables_agentic import ParseConfigBlockOptionsTablesAgenticParams


class ParseConfigBlockOptionsTablesParams(typing_extensions.TypedDict):
    """
    Options for table blocks.
    """

    enabled: typing_extensions.NotRequired[bool]
    """
    This option is deprecated and will have no effect. It will be removed in the next API version.
    """

    target_format: typing_extensions.NotRequired[
        typing_extensions.Annotated[ParseConfigBlockOptionsTablesTargetFormat, FieldMetadata(alias="targetFormat")]
    ]
    """
    The target format for the table blocks. Supported values:
    * `markdown`: Convert table to Markdown format
    * `html`: Convert table to HTML format
    """

    table_header_continuation_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="tableHeaderContinuationEnabled")]
    ]
    """
    Whether to automatically copy table headers to headerless tables on subsequent pages when they have matching column counts. Useful for multi-page tables.
    """

    cell_blocks_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="cellBlocksEnabled")]
    ]
    """
    Whether to include individual table cell blocks in the output. When enabled, each cell in a table will be represented as a separate block with its own bounding box and content and will be `children` of the table block.
    """

    agentic: typing_extensions.NotRequired[ParseConfigBlockOptionsTablesAgenticParams]
    """
    Options for agentic table processing using VLM-based review and correction.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .classify_run import ClassifyRunParams


class ClassifyResultParams(typing_extensions.TypedDict):
    """
    The result of a classify step.
    """

    classify_run: typing_extensions.Annotated[ClassifyRunParams, FieldMetadata(alias="classifyRun")]
    """
    The classify run that was executed.
    """



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .chunk import Chunk
from .parse_run_output_ocr import ParseRunOutputOcr


class ParseRunOutput(UncheckedBaseModel):
    """
    The parse run output.

    **Availability:** Present when `status` is `"PROCESSED"` and the request was made without the `responseType=url` query parameter. Contains the parsed chunks.
    """

    chunks: typing.List[Chunk] = pydantic.Field()
    """
    An array of chunks that were parsed from the file.
    """

    ocr: typing.Optional[ParseRunOutputOcr] = pydantic.Field(default=None)
    """
    Raw OCR data from the parsing process. Only included when `returnOcr` is configured in the parse config's advanced options.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ParseRunOutput)



# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_result import ExtractResultParams
from .extract_step_run_step import ExtractStepRunStepParams
from .step_run_base import StepRunBaseParams


class ExtractStepRunParams(StepRunBaseParams):
    step: ExtractStepRunStepParams
    result: typing.Optional[ExtractResultParams]
    """
    The result of this extract step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
